nagios_host 'akjournals.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'AK Journals',
		'address' => 'akjournals.com',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AK/pages/659816852/Server+Setup+-+Akad+miai+Kiad'
end
nagios_host 'admin.akjournals.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'AK MGMT Portal',
		'address' => 'admin.akjournals.com',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AK/pages/659816852/Server+Setup+-+Akad+miai+Kiad'
end
nagios_host 'ams.akjournals.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'AK AMX',
		'address' => 'ams.akjournals.com',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AK/pages/659816852/Server+Setup+-+Akad+miai+Kiad'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AK site and checks for the string 'AKJournals'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!ak:ak2018!/!"AKJournals"!10!20!',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Live Site',
		'notes_url' => 'https://akjournals.com'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live AK site and checks for the string ''.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!ak:ak2018!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Live Site',
		'notes_url' => 'https://akjournals.com/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AK site and checks for the string 'AKJournals'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!ak:ak2018!/view/journals/2054/2054-overview.xml!AKJournals!10!20!',
		'contact_groups' => 'cs_escalation,ak',
		'notes' => 'AK Live Site',
		'notes_url' => 'https://akjournals.com/view/journals/2054/2054-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'AK PROD' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin.akjournals.com',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.akjournals.com!/login!ak:ak2018!"AK Production"!20!10',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK Live Loader',
		'notes_url' => 'https://admin.akjournals.com/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'AKJournals' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.akjournals.com!ak:ak2018!"AKJournals"!20!10',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK Staging Site',
		'notes_url' => 'staging.akjournals.com'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams.akjournals.com',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.akjournals.com!/login!ak:ak2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK AMX',
		'notes_url' => 'https://ams.akjournals.com/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!akjournals.com!ak:ak2018!"provisional account"',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK Live Site Failopen',
		'notes_url' => 'https://akjournals.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live AK site on the first web node and checks for the string 'AKJournals'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Homepage: web-16' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live Homepage: web-16',
		'check_command' => 'https_content_check_basic_auth_single_node!ak:ak2018!/!AKJournals!10!20!ak-web-live16!web-16!',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK Live Site: web-16',
		'notes_url' => 'akjournals.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live AK site on the first web node and checks for the string 'AK'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Homepage: web-17' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'akjournals.com',
		'display_name' => 'Live Homepage: web-17',
		'check_command' => 'https_content_check_basic_auth_single_node!ak:ak2018!/!AKJournals!10!20!ak-web-live17!web-17!',
		'contact_groups' => 'admins_email_only,ak',
		'notes' => 'AK Live Site: web-17',
		'notes_url' => 'akjournals.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (Node 3)
# Checks the homepage of the live AK site on the bot web node and checks for the string 'AKJournals'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'akjournals.com-Live Homepage: ak-web-bot-24 bot node' do
        options 'use' => 'sbo-service-pf',
                'host_name' => 'akjournals.com',
                'display_name' => 'Live Homepage: ak-web-bot-24',
                'check_command' => 'https_content_check_basic_auth_single_node_bot!ak:ak2018!/!AKJournals!10!20!ak-web-bot-live24!web-24!',
                'contact_groups' => 'admins_email_only,ak',
                'notes' => 'AK Bot Site: ak-web-bot-24',
                'notes_url' => 'https://akjournals.com/'
end
